/*-
 * Copyright (c) 2009 Pietro Cerutti <gahr@gahr.ch>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <stdio.h>
#include <limits.h>

#include "callbacks.h"
#include "gui_helper.h"
#include "chans.h"

CALLBACK_FUNC(window_destroy)
{
	ewl_widget_destroy(_w);
	epromix_quit();
}

CALLBACK_FUNC(window_keyup)
{
	Ewl_Event_Key *ev = (Ewl_Event_Key *)_e;

	if ((ev->modifiers & EWL_KEY_MODIFIER_CTRL) == ev->modifiers &&
		!strcmp(ev->keyname, "q")) {
		window_destroy(_w, _e, _d);
	}
}

CALLBACK_FUNC(gain_seeker_value_change)
{
	Ewl_Range *r = (Ewl_Range *)_w;
	chan_t c = (chan_t )_d;
	mixer_set_chan_gain(c, r->value, r->value);
	update_chans(NULL);
	/* we let the Ecore timer update the seekers */
}

CALLBACK_FUNC(gain_seeker_mouse_wheel)
{
	Ewl_Range *r = (Ewl_Range *)_w;
	Ewl_Event_Mouse_Wheel *wheel = (Ewl_Event_Mouse_Wheel *)_e;
	ewl_range_value_set(r, r->value - (wheel->z * r->step));
}

CALLBACK_FUNC(menu_quit)
{
	window_destroy(_w, _e, _d);
}

CALLBACK_FUNC(menu_mixer_dev_choose)
{
	char buf[PATH_MAX];
	Ewl_Button *b = (Ewl_Button *)_w;
	snprintf(buf, PATH_MAX-1, "/dev/%s", ewl_button_label_get(b));
	mixer_destroy();
	mixer_init(buf);
	reload_chans();
}

CALLBACK_FUNC(menu_profile_save)
{
	printf("Save profile\n");
}

CALLBACK_FUNC(menu_profile_save_as)
{
	printf("Save profile as...\n");
}

CALLBACK_FUNC(menu_profile_reset)
{
	const chan_t *chans = mixer_get_chans();
	int i = mixer_get_nof_chans();
	while (i--) {
		mixer_set_chan_gain(chans[i], 0, 0);
	}
}
