/*-
 * Copyright (c) 2009 Pietro Cerutti <gahr@gahr.ch>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <stdio.h>
#include <stdlib.h>

#include <Ewl.h>
#include <Ecore.h>

#include "callbacks.h"
#include "menubar.h"
#include "chans.h"
#include "gui_helper.h"

#define EPROMIX_PROG "eProMix"
#define EPROMIX_VERS "0.1.0"
int
main(int argc, char **argv)
{
	int i;

	if (!ewl_init(&argc, argv)) {
		return (EXIT_FAILURE);
	}

	if (mixer_init("/dev/mixer")) {
		return (EXIT_FAILURE);
	}

	int nof_chans = mixer_get_nof_chans();

	/* main window */
	epromix_win = ewl_window_new();
	ewl_window_title_set(EWL_WINDOW(epromix_win), EPROMIX_PROG " " EPROMIX_VERS);
	ewl_window_class_set(EWL_WINDOW(epromix_win), EPROMIX_PROG);
	ewl_window_name_set(EWL_WINDOW(epromix_win), EPROMIX_PROG);
	ewl_callback_append(epromix_win, EWL_CALLBACK_DELETE_WINDOW, window_destroy, NULL);
	ewl_callback_append(epromix_win, EWL_CALLBACK_KEY_UP, window_keyup, NULL);
	ewl_widget_show(epromix_win);

	/* vertical box */
	Ewl_Widget *vbox = ewl_vbox_new();
	ewl_container_child_append(EWL_CONTAINER(epromix_win), vbox);
	ewl_object_fill_policy_set(EWL_OBJECT(vbox), EWL_FLAG_FILL_ALL);
	ewl_widget_show(vbox);
	create_menubar(EWL_CONTAINER(vbox));

	/* Vertical spacer */
	Ewl_Widget *vspacer = ewl_spacer_new();
	ewl_container_child_append(EWL_CONTAINER(vbox), vspacer);
	ewl_object_minimum_size_set(EWL_OBJECT(vspacer), 15, 15);
	ewl_object_maximum_size_set(EWL_OBJECT(vspacer), 15, 15);
	ewl_widget_show(vspacer);

	/* Horizontal box */
	Ewl_Widget *box = ewl_hbox_new();
	ewl_container_child_append(EWL_CONTAINER(vbox), box);
	ewl_object_fill_policy_set(EWL_OBJECT(box), EWL_FLAG_FILL_ALL);
	ewl_widget_show(box);

	/* create chans widgets */
	create_chans(EWL_CONTAINER(box));
	Ecore_Timer *t;
	t = ecore_timer_add(1, update_chans, NULL);

	update_chans(NULL);

	ewl_main();
	return (EXIT_SUCCESS);
}
