/*-
 * Copyright (c) 2009 Pietro Cerutti <gahr@gahr.ch>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <sys/types.h>
#include <dirent.h>

#include "callbacks.h"
#include "menubar.h"

/*
 * Menu bar
 *	-> Mixer
 *		-> Devices
 *			-> Mixer 0
 *			-> Mixer 1
 *			-> ..
 *		-> Quit
 *	-> Profiles
 *		-> Load
 *			-> Profile 0
 *			-> Profile 1
 *		-> Save
 *		-> Save as...
 *		-> Reset
 */

void
create_menubar(Ewl_Container *container)
{
	/* Menu bar */
	{
		Ewl_Widget *menuBar = ewl_menubar_new();
		ewl_object_alignment_set(EWL_OBJECT(menuBar), EWL_FLAG_ALIGN_LEFT);
		ewl_object_fill_policy_set(EWL_OBJECT(menuBar), EWL_FLAG_FILL_HSHRINK);
		ewl_container_child_append(container, menuBar);
		ewl_widget_show(menuBar);

		/* Mixer menu */
		{
			Ewl_Widget *menu = ewl_menu_new();
			ewl_button_label_set(EWL_BUTTON(menu), "Mixer");
			ewl_container_child_append(EWL_CONTAINER(menuBar), menu);
			ewl_widget_show(menu);

			/* Devices */
			{
				Ewl_Widget *item = ewl_menu_new();
				ewl_button_label_set(EWL_BUTTON(item), "Devices");
				ewl_container_child_append(EWL_CONTAINER(menu), item);
				ewl_widget_show(item);

				/* scan devices */
				do {
					DIR *d;
					struct dirent *ent;

					if (!(d= opendir("/dev/"))) {
						break;
					}

					while ((ent = readdir(d))) {
						if (ent->d_namlen < 6 || strncmp(ent->d_name, "mixer", 5)) {
							continue;
						}
						Ewl_Widget *mixerDevEntry = ewl_menu_item_new();
						ewl_button_label_set(EWL_BUTTON(mixerDevEntry), ent->d_name);
						ewl_container_child_append(EWL_CONTAINER(item), mixerDevEntry);
						ewl_callback_append(mixerDevEntry, EWL_CALLBACK_CLICKED, menu_mixer_dev_choose, NULL);
						ewl_widget_show(mixerDevEntry);
					}
					closedir(d);
				} while (0);
			}

			/* Quit */
			{
				Ewl_Widget *item = ewl_menu_item_new();
				ewl_button_label_set(EWL_BUTTON(item), "Quit");
				ewl_callback_append(item, EWL_CALLBACK_CLICKED, menu_quit, NULL);
				ewl_container_child_append(EWL_CONTAINER(menu), item);
				ewl_widget_show(item);
			}
		}

		/* Spacer */
		Ewl_Widget *spacer = ewl_spacer_new();
		ewl_object_fill_policy_set(EWL_OBJECT(spacer), EWL_FLAG_FILL_ALL);
		ewl_container_child_append(EWL_CONTAINER(menuBar), spacer);
		ewl_widget_show(spacer);

		/* Profiles */
		{
			Ewl_Widget *menu = ewl_menu_new();
			ewl_button_label_set(EWL_BUTTON(menu), "Profiles");
			ewl_container_child_append(EWL_CONTAINER(menuBar), menu);
			ewl_widget_show(menu);

			/* Load */
			{
				Ewl_Widget *item = ewl_menu_new();
				ewl_button_label_set(EWL_BUTTON(item), "Load");
				ewl_container_child_append(EWL_CONTAINER(menu), item);
				ewl_widget_show(item);

				/*
				 * @TODO Implement scan profiles
				 */
			}

			/* Save */
			{
				Ewl_Widget *item = ewl_menu_item_new();
				ewl_button_label_set(EWL_BUTTON(item), "Save");
				ewl_container_child_append(EWL_CONTAINER(menu), item);
				ewl_callback_append(item, EWL_CALLBACK_CLICKED, menu_profile_save, NULL);
				ewl_widget_show(item);
			}

			/* Save as */
			{
				Ewl_Widget *item = ewl_menu_item_new();
				ewl_button_label_set(EWL_BUTTON(item), "Save as...");
				ewl_container_child_append(EWL_CONTAINER(menu), item);
				ewl_callback_append(item, EWL_CALLBACK_CLICKED, menu_profile_save_as, NULL);
				ewl_widget_show(item);
			}

			/* Reset */
			{
				Ewl_Widget *item = ewl_menu_item_new();
				ewl_button_label_set(EWL_BUTTON(item), "Reset");
				ewl_container_child_append(EWL_CONTAINER(menu), item);
				ewl_callback_append(item, EWL_CALLBACK_CLICKED, menu_profile_reset, NULL);
				ewl_widget_show(item);
			}
		}
	}

}
