#include "mixer.h"
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

int main(int argc, char **argv)
{
	if (argc != 2) {
		fprintf(stderr, "Usage: %s <device>\n", argv[0]);
		return (EXIT_FAILURE);
	}

	/* mixer */
	if (mixer_init(argv[1])) {
		fprintf(stderr, "Could not initialize mixer device <%s>\n", argv[1]);
		return (EXIT_FAILURE);
	}

	/* number of (available) channels */
	int nof_chans = mixer_get_nof_chans();
	const chan_t *chans = mixer_get_chans();
	printf("Number of chans: %d\n", nof_chans);

	/* print channels */
	int i, left, right;
	for (i = 0; i < nof_chans; i++) {
		mixer_get_chan_gain(chans[i], &left, &right);
		printf("Chan %02d %-8s [%2d:%2d] (%s%s)\n",
				chans[i], mixer_get_chan_name(chans[i]), left, right,
				mixer_can_record(chans[i]) ? "rec " : "",
				mixer_is_recording(chans[i]) ? "ON" : "");

		if (!strcmp(mixer_get_chan_name(chans[i]), "line")) {
			if (mixer_set_recording(chans[i]) == -1) {
				printf("cannot set recording source");
			}
		}

	}

	mixer_destroy();

	return (EXIT_SUCCESS);
}
